# x16rt_hash
Python bindings for the x16rt hash function used in Veil cryptocurrency PoW.

## Prerequisites

```
sudo apt-get install python-dev
```

## Installation

To install this module, clone this repository and run:

```
python setup.py install
```

You can verify the installation by running:

```
python test.py
```
